@@ -4,9 +4,7 @@ Commands contributed by setupmeta
 
 import collections
 import os
-import platform
 import shutil
-import sys
 from distutils.command.check import check as check_cmd
 from itertools import chain
 
@@ -24,18 +22,6 @@ def abort(message):
     raise DistutilsSetupError(message)
 
 
-def get_pip_config(key, default=None):
-    """Configured pip key, if available (from ~/.config/pip/pip.conf or /etc/pip.conf)"""
-    try:
-        from pip._internal.configuration import Configuration
-        cc = Configuration(isolated=False)
-        cc.load()
-        return cc.get_value(key)
-
-    except (Exception, ImportError):
-        return default
-
-
 def MetaCommand(cls):
     """Decorator allowing for less boilerplate in our commands"""
     return setupmeta.MetaDefs.register_command(cls)
@@ -51,82 +37,6 @@ def longest_line(lines, maximum=70):
     return min(longest, maximum)
 
 
-@MetaCommand
-class UberEggCommand(setuptools.Command):
-    """pack all dependencies as eggs"""
-
-    user_options = [
-        ('dist=', 'd', "directory to put eggs in"),
-        ("requirements=", "r", "grab egg for all dependencies listed in given requirements file"),
-    ]
-
-    def initialize_options(self):
-        self.dist = None
-        self.requirements = None
-
-    def _get_requirements(self):
-        if self.requirements:
-            from setupmeta.content import load_list
-
-            raw = load_list(self.requirements) or []
-            reqs = [r for r in raw if r and not r.startswith("-")]
-            setupmeta.trace("Extracted %s/%s reqs from %s" % (len(raw), len(reqs), self.requirements))
-            return reqs
-
-    def run(self):
-        """
-        Grab an egg for each requirement, if any.
-        This is useful to mimic spark's "uber-jars" (https://spark.apache.org/docs/latest/index.html)
-        """
-        if self.dist is None:
-            self.dist = "dist"
-
-        if self.requirements is None:
-            self.requirements = "requirements.txt"
-
-        egg_target = os.path.abspath(self.dist)
-        if not os.path.isdir(egg_target):
-            os.mkdir(egg_target)
-
-        reqs = self._get_requirements()
-        print("%s dependencies in %s" % (len(reqs), self.requirements))
-        if reqs:
-            with setupmeta.temp_resource():
-                easy_install = os.path.join(os.path.dirname(sys.executable), "easy_install")
-                common_args = ["-zax", "-d", "."]
-                index_url = get_pip_config("global.index-url")
-                if index_url:  # pragma: no cover, only applicable if one has configured index url
-                    common_args.append("-i")
-                    common_args.append(index_url)
-
-                env = dict(os.environ)
-                env["PYTHONPATH"] = "."
-                for req in reqs:
-                    args = common_args[:]
-                    args.append(req)
-                    setupmeta.run_program(easy_install, *args, env=env)
-
-                eggs = [f for f in os.listdir(".") if f.endswith(".egg")]
-                print("Fetched %s eggs" % len(eggs))
-                for name in eggs:
-                    dest = os.path.join(egg_target, name)
-                    if os.path.exists(dest):  # pragma: no cover
-                        print("%s/%s already exists, skipping" % (self.dist, name))
-                        continue
-
-                    source = name
-                    action = "Grabbed"
-                    if os.path.isdir(source):
-                        # This disregards any `zip_safe=False` setting, this could be wrong
-                        # However, most libraries don't specify this, even though their project is zip-safe...
-                        # Spark users seem to get by with eggs just fine, so forcing a zip here
-                        action = "Force-zipped"
-                        source = shutil.make_archive(name, "zip", source)
-
-                    print("%s %s" % (action, name))
-                    shutil.copy2(source, dest)
-
-
 @MetaCommand
 class CheckCommand(check_cmd):
     """Perform checks on the package"""
@@ -164,19 +74,20 @@ class CheckCommand(check_cmd):
 
     def _show_requirements_synopsis(self):
         """Show how many requirements were auto-abstracted or ignored, if any"""
-        reqs = self.setupmeta.requirements.install_requires
-        if reqs and (reqs.abstracted or reqs.ignored or reqs.dependency_links):
-            message = "[setupmeta] install_requires: %s abstracted, %s ignored, %s untouched" % (
-                len(reqs.abstracted),
-                len(reqs.ignored),
-                len(reqs.untouched),
-            )
+        reqs = self.setupmeta.requirements
+        if reqs and reqs.has_abstractions:
+            reqs = reqs.install_requires
+            if reqs.filled_requirements and (reqs.abstracted or reqs.ignored or reqs.dependency_links):
+                message = "[setupmeta] install_requires: %s abstracted, %s ignored, %s untouched" % (
+                    len(reqs.abstracted),
+                    len(reqs.ignored),
+                    len(reqs.untouched),
+                )
 
-            dependency_links = self.setupmeta.requirements.dependency_links or reqs.dependency_links
-            if dependency_links:
-                message += ", %s dependency links" % len(dependency_links)
+                if reqs.dependency_links:
+                    message += ", %s dependency links" % len(reqs.dependency_links)
 
-            print(message)
+                print(message)
 
     def _show_git_status(self):
         if self.setupmeta.versioning:
@@ -246,11 +157,11 @@ class ExplainCommand(setuptools.Command):
             hint = ", %s" % hint if hint else ""
             self.setupmeta.auto_fill(key, "- Consider specifying '%s'%s" % (key, hint), "missing")
 
-    def represented_req(self, name, note=None, align=None):
+    def represented_req(self, name, source_description, align):
         name = '"%s",' % name
-        if note:
+        if source_description:
             fmt = "%%-%ss# %%s" % align
-            name = fmt % (name, note)
+            name = fmt % (name, source_description)
 
         return name
 
@@ -260,22 +171,19 @@ class ExplainCommand(setuptools.Command):
         :param setupmeta.RequirementsFile requirements:
         """
         content = "None,   # no auto-fill"
-        if requirements and requirements.filled_requirements:
-            names = []
-            notes = []
-            for line_req in requirements.lines:
-                if line_req.abstracted:
-                    names.append(line_req.abstracted)
-                    notes.append(line_req.note or "")
+        names = []
+        source_descriptions = []
+        if requirements:
+            for req_entry in requirements.reqs:
+                if req_entry.requirement and not req_entry.is_ignored and req_entry.requirement not in names:
+                    names.append(req_entry.requirement)
+                    source_descriptions.append(req_entry.source_description)
 
-            if any(len(note) for note in notes):
-                longest_name = max(len(name) for name in names) + 5
-                content = []
-                for i in range(len(names)):
-                    content.append(self.represented_req(names[i], notes[i], longest_name))
-
-            else:
-                content = [self.represented_req(name) for name in names]
+        if names:
+            longest_name = max(len(name) for name in names) + 5
+            content = []
+            for i, name in enumerate(names):
+                content.append(self.represented_req(name, source_descriptions[i], longest_name))
 
             content = "[\n        %s\n    ]," % "\n        ".join(content).strip()
 
@@ -301,7 +209,7 @@ class ExplainCommand(setuptools.Command):
 
         version = definitions.get("version")
         if version:
-            print('__version__ = %s\n\n' % setupmeta.stringify(version.value, quote=True))
+            print("__version__ = %s\n\n" % setupmeta.stringify(version.value, quote=True))
 
         print("setup(")
 
@@ -329,7 +237,7 @@ class ExplainCommand(setuptools.Command):
                     definition.value = setupmeta.stringify(definition.value, quote=True, indent="        ")
 
             elif definition.key == "long_description":
-                definition.value = 'open(%s).read()' % setupmeta.stringify(setupmeta.short(definition.source), quote=True)
+                definition.value = "open(%s).read()" % setupmeta.stringify(setupmeta.short(definition.source), quote=True)
 
             elif definition.key == "version":
                 definition.value = "__version__"
@@ -384,7 +292,6 @@ class ExplainCommand(setuptools.Command):
         self.check_recommend("long_description", "add a README file")
         if self.recommend:
             self.check_recommend("author")
-            self.check_recommend("classifiers")
             self.check_recommend("download_url")
             self.check_recommend("license")
             self.check_recommend("url")
@@ -532,97 +439,6 @@ class CleanCommand(setuptools.Command):
             print("all clean, no deletable files found")
 
 
-@MetaCommand
-class TwineCommand(setuptools.Command):
-    """upload binary package to PyPI using twine"""
-
-    user_options = [
-        ("commit", "c", "commit publishing (dryrun by default)"),
-        ("rebuild", "r", "clean and rebuild before publishing"),
-        ("egg=", "e", "build/publish egg"),
-        ("sdist=", "s", "build/publish source distribution"),
-        ("wheel=", "w", "build/publish wheel"),
-    ]
-
-    def initialize_options(self):
-        major, minor = (sys.version_info.major, sys.version_info.minor)
-        self.current_python = ["%s.%s" % (major, minor), "%s%s" % (major, minor)]
-        self.commit = 0
-        self.rebuild = 0
-        self.egg = None
-        self.sdist = None
-        self.wheel = None
-
-    def clean(self, *relative_paths):
-        for relative_path in relative_paths:
-            path = setupmeta.project_path(relative_path)
-            if not os.path.exists(path):
-                continue
-
-            if self.commit:
-                print("Deleting %s..." % path)
-                shutil.rmtree(path)
-
-            else:
-                print("Would delete %s" % path)
-
-    def should_run(self, value):
-        return value == "all" or value in self.current_python
-
-    def run_command(self, message, *args):
-        if not self.commit:
-            print("Would %s: %s" % (message, setupmeta.represented_args(args)))
-            return
-
-        first, _, rest = message.partition(" ")
-        first = "%s%s" % (first[0].upper(), first[1:])
-        message = "%sing %s..." % (first, rest)
-        print(message)
-        setupmeta.run_program(*args, fatal=True)
-
-    def run(self):
-        if not self.setupmeta:
-            return
-
-        if platform.python_implementation() != "CPython":
-            abort("twine command not supported on %s" % platform.python_implementation())
-
-        if not self.egg and not self.sdist and not self.wheel:
-            abort("Specify at least one of: --egg, --dist or --wheel")
-
-        # Env var SETUPMETA_TWINE primarily used to allow for flexible testing
-        # Can be set to instruct setupmeta to use a particular twine executable as well
-        # Use absolute path, of filename (for example: "my-twine-wrapper")
-        twine = setupmeta.which(os.environ.get("SETUPMETA_TWINE", "twine"))
-        if not twine:
-            abort("twine is not installed")
-
-        if not self.commit:
-            print("Dryrun, use --commit to effectively build/publish")
-
-        dist = setupmeta.project_path("dist")
-        self.clean("dist", "build")
-
-        try:
-            if self.should_run(self.egg):
-                self.run_command("build egg distribution", sys.executable, "setup.py", "bdist_egg")
-
-            if self.should_run(self.sdist):
-                self.run_command("build source distribution", sys.executable, "setup.py", "sdist")
-
-            if self.should_run(self.wheel):
-                self.run_command("build wheel distribution", sys.executable, "setup.py", "bdist_wheel", "--universal")
-
-            if self.commit and not os.path.exists(dist):
-                abort("No files found in %s" % dist)
-
-            files = [os.path.join(dist, name) for name in sorted(os.listdir(dist))] if self.commit else ["dist/*"]
-            self.run_command("upload to PyPi via twine", twine, "upload", *files)
-
-        finally:
-            self.clean("build")
-
-
 def _show_dependencies(definitions):
     """
     Conveniently  get dependency tree via ./setup.py check --dep, similar to https://pypi.org/project/pipdeptree
@@ -774,7 +590,7 @@ def find_venv():
 class DepTree:
     def __init__(self, ws, definitions):
         self.packages = dict((d.key, PipPackage(self, d)) for d in ws)
-        self.setup = definitions.get("setup_requires"),
+        self.setup = definitions.get("setup_requires")
         self.install_requires = definitions.get("install_requires")
         self.tests_require = definitions.get("tests_require")
         self.extras_require = definitions.get("extras_require")
@@ -818,9 +634,7 @@ class DepTree:
 
             result = ["%s%s" % (" " * indent, node.render())]
             children = sorted(self.get_children(node))
-            children = [aux(c, indent=indent + 2, chain=chain + [c.key])
-                        for c in children
-                        if c.key not in chain]
+            children = [aux(c, indent=indent + 2, chain=chain + [c.key]) for c in children if c.key not in chain]
 
             chain.append(node.key)
             p = self.packages.get(node.key)
